# meta-eukaryome-detect


[![pypi](https://img.shields.io/pypi/v/meta-eukaryome-detect.svg)](https://pypi.org/project/meta-eukaryome-detect/)
[![licence](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)


Pathogen, Parasite, Eukaryote and Virus detection in metagenomes.


* Documentation: <https://grp-bork.embl-community.io/grp-microbiome-astrology/meta_eukaryome_detect/>
* GitHub: <https://git.embl.de/grp-bork/meta_eukaryome_detect>
* PyPI: <https://pypi.org/project/meta-eukaryome-detect/>
* Free software: MIT
